@@ -78,6 +78,7 @@ Utility functions and constants usable in various circumstances.
   :py:func:`set_json_key_value_overrides`,
   :py:func:`assert_file_grp_cardinality`,
   :py:func:`make_file_id`
+  :py:func:`generate_range`
 
     String and OOP utilities
 
@@ -173,6 +174,7 @@ from .os import (
 from .str import (
     assert_file_grp_cardinality,
     concat_padded,
+    generate_range,
     get_local_filename,
     is_local_filename,
     is_string,
